==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_WeatherData.pm <==
package WebGUI::i18n::German::Asset_WeatherData;
use utf8;
our $I18N = {
  'Current Weather Conditions Template to use' => {
    'lastUpdated' => 1226015304,
    'message' => 'Genutzte Vorlage'
  },
  'Default Locations' => {
    'lastUpdated' => 1226015275,
    'message' => 'Standard-Orte'
  },
  'Template' => {
    'lastUpdated' => 1212756624,
    'message' => 'Vorlage'
  },
  'WeatherData template title' => {
    'lastUpdated' => 1228689971,
    'message' => 'Wetterdaten-Vorlage'
  },
  'Your list of default weather locations' => {
    'lastUpdated' => 1228690025,
    'message' => '<p>Ihre Liste der Wetter-Orte, jeden auf einer eigenen Zeile:</p><p>City, ST || Zip Code || City, Country </p>'
  },
  'assetName' => {
    'lastUpdated' => 1226015253,
    'message' => 'Wetterdaten'
  },
  'cityState' => {
    'lastUpdated' => 1228690074,
    'message' => 'Die Stadt und der Staat der NOAA. Dies ist oft das gleich wie <strong>query</strong>'
  },
  'iconUrl' => {
    'lastUpdated' => 1228690106,
    'message' => 'Der URL zu einem Icon, das die Wetterlage visualisiert.'
  },
  'licenseKey' => {
    'lastUpdated' => 1228690124,
    'message' => 'Lizenzschlüssel f&uuml;r weather.com'
  },
  'licenseKey help' => {
    'lastUpdated' => 1228690293,
    'message' => 'Sie haben diesen Schlüssel von weather.com per E-Mail erhalten, nachdem Sie sich f&uuml;r den Weather XML Data Feed angemeldet hatten.'
  },
  'locations' => {
    'lastUpdated' => 1226015162,
    'message' => 'Die Liste der Orte, die der Nutzer eingegeben hat'
  },
  'ourLocations.loop' => {
    'lastUpdated' => 1228690230,
    'message' => 'eine Schleife, die Wetterinformationen zu allen konfigurierten Benutzer-Orten enthält.'
  },
  'partnerId' => {
    'lastUpdated' => 1228690250,
    'message' => 'Partner-Id für weather.com'
  },
  'partnerId help' => {
    'lastUpdated' => 1228690286,
    'message' => 'Sie haben diese ID von weather.com per E-Mail erhalten, nachdem Sie sich für den Weather XML Data Feed angemeldet hatten.'
  },
  'query' => {
    'lastUpdated' => 1212756698,
    'message' => 'der gewünschte Ort'
  },
  'sky' => {
    'lastUpdated' => 1212756742,
    'message' => 'Wetterlage (klar, sonnig, bedeckt)'
  },
  'tempF' => {
    'lastUpdated' => 1212756758,
    'message' => 'Temperatur in Fahrenheit'
  },
  'templateId' => {
    'lastUpdated' => 1228690321,
    'message' => 'Die ID der Vorlage, die genutzt wird um dieses Asset anzuzeigen.'
  },
  'weatherdata asset template variables title' => {
    'lastUpdated' => 1228690336,
    'message' => '<div align="left">WeatherData Asset Template Variables</div>'
  },
  'you need a weather.com key' => {
    'lastUpdated' => 1226015232,
    'message' => 'Klicken Sie hier, zum sich auf weather.com für den kostenlosen &quot;Weacher XML Data Feed&quot; zu registrieren. Dieser wird f&uuml;r dieses Asset zwingend benötigt.'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_WeatherData.pm <==
package WebGUI::i18n::German::Asset_WeatherData;
use utf8;
our $I18N = {
  'Current Weather Conditions Template to use' => {
    'lastUpdated' => '1226015304',
    'message' => 'Genutzte Vorlage'
  },
  'Default Locations' => {
    'lastUpdated' => '1226015275',
    'message' => 'Standard-Orte'
  },
  'Template' => {
    'lastUpdated' => '1212756624',
    'message' => 'Vorlage'
  },
  'WeatherData template title' => {
    'lastUpdated' => '1228689971',
    'message' => 'Wetterdaten-Vorlage'
  },
  'Your list of default weather locations' => {
    'lastUpdated' => '1228690025',
    'message' => '<p>Ihre Liste der Wetter-Orte, jeden auf einer eigenen Zeile:</p><p>City, ST || Zip Code || City, Country </p>'
  },
  'assetName' => {
    'lastUpdated' => '1226015253',
    'message' => 'Wetterdaten'
  },
  'cache timeout help' => {
    'lastUpdated' => '1301989003',
    'message' => 'Wie lange sollen Abfragen für jeden Ort intern gecached werden?'
  },
  'cityState' => {
    'lastUpdated' => '1228690074',
    'message' => 'Die Stadt und der Staat der NOAA. Dies ist oft das gleich wie <strong>query</strong>'
  },
  'iconUrl' => {
    'lastUpdated' => '1228690106',
    'message' => 'Der URL zu einem Icon, das die Wetterlage visualisiert.'
  },
  'licenseKey' => {
    'lastUpdated' => '1228690124',
    'message' => 'Lizenzschlüssel f&uuml;r weather.com'
  },
  'licenseKey help' => {
    'lastUpdated' => '1228690293',
    'message' => 'Sie haben diesen Schlüssel von weather.com per E-Mail erhalten, nachdem Sie sich f&uuml;r den Weather XML Data Feed angemeldet hatten.'
  },
  'locations' => {
    'lastUpdated' => '1226015162',
    'message' => 'Die Liste der Orte, die der Nutzer eingegeben hat'
  },
  'ourLocations.loop' => {
    'lastUpdated' => '1228690230',
    'message' => 'eine Schleife, die Wetterinformationen zu allen konfigurierten Benutzer-Orten enthält.'
  },
  'partnerId' => {
    'lastUpdated' => '1228690250',
    'message' => 'Partner-Id für weather.com'
  },
  'partnerId help' => {
    'lastUpdated' => '1228690286',
    'message' => 'Sie haben diese ID von weather.com per E-Mail erhalten, nachdem Sie sich für den Weather XML Data Feed angemeldet hatten.'
  },
  'query' => {
    'lastUpdated' => '1212756698',
    'message' => 'der gewünschte Ort'
  },
  'sky' => {
    'lastUpdated' => '1212756742',
    'message' => 'Wetterlage (klar, sonnig, bedeckt)'
  },
  'tempF' => {
    'lastUpdated' => '1212756758',
    'message' => 'Temperatur in Fahrenheit'
  },
  'templateId' => {
    'lastUpdated' => '1228690321',
    'message' => 'Die ID der Vorlage, die genutzt wird um dieses Asset anzuzeigen.'
  },
  'weatherdata asset template variables title' => {
    'lastUpdated' => '1228690336',
    'message' => '<div align="left">WeatherData Asset Template Variables</div>'
  },
  'you need a weather.com key' => {
    'lastUpdated' => '1226015232',
    'message' => 'Klicken Sie hier, zum sich auf weather.com für den kostenlosen &quot;Weacher XML Data Feed&quot; zu registrieren. Dieser wird f&uuml;r dieses Asset zwingend benötigt.'
  }
}
;

1;
